package com.ppopescu;

import org.apache.logging.log4j.core.LogEvent;
import org.apache.logging.log4j.core.config.plugins.Plugin;
import org.apache.logging.log4j.core.pattern.ConverterKeys;
import org.apache.logging.log4j.core.pattern.LogEventPatternConverter;
import org.apache.logging.log4j.core.pattern.PatternConverter;

import java.util.Arrays;
import java.util.HashSet;
import java.util.Set;

@Plugin(name = "highlight", category = PatternConverter.CATEGORY)
@ConverterKeys({"color", "colormsg"})
public class HighlightConverter extends LogEventPatternConverter {
    private static final String NO_COLOR = "\u001B[0m";
    private static final String HIGHLIGHT_COLOR = "\u001B[96m";

    private Set<String> words;

    private HighlightConverter(Set<String> words) {
        super("HighlightConverter", null);

        this.words = words;
    }

    public static HighlightConverter newInstance(String[] options) {
        return new HighlightConverter(new HashSet<>(Arrays.asList(options)));
    }



    @Override
    public void format(LogEvent event, StringBuilder toAppendTo) {
        String logMessage = event.getMessage().getFormattedMessage();
        for (String word:words) {
            logMessage = logMessage.replaceAll(word, HIGHLIGHT_COLOR + word + NO_COLOR);
        }

        toAppendTo.append(logMessage);
    }
}
